@@ -88,4 +88,4 @@ OC.L10N.register(
     "Mail" : "Correo",
     "Birthday" : "Fecha de nacimiento"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
