@@ -40,7 +40,7 @@ OC.L10N.register(
     "An error occurred, unable to change the calendar's color." : "Terjadi galat, tidak dapat mengganti warna kalender.",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Batal berbagi kalender dalam {countdown} detik"],
     "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Menghapus kalender dalam {countdown} detik"],
-    "Share link" : "Bagi tautan",
+    "Share link" : "Bagikan tautan",
     "Publish calendar" : "Menerbitkan kalender",
     "Publishing calendar" : "Menerbitkan kalender",
     "Copy public link" : "Salin tautan publik",
@@ -197,6 +197,7 @@ OC.L10N.register(
     "Please enter a valid date" : "Silakan isi tanggal valid",
     "Please enter a valid date and time" : "Silakan isi tanggal dan waktu valid",
     "Personal" : "Pribadi",
+    "[Today]" : "[Hari ini]",
     "Details" : "Detail",
     "Attendees" : "Peserta",
     "Close" : "Tutup",
@@ -261,6 +262,7 @@ OC.L10N.register(
     "Custom color" : "Warna khusus",
     "Special color of this event. Overrides the calendar-color." : "Warna spesial dari acara ini. Mengganti warna kalender.",
     "Chat room for event" : "Ruang obrolan untuk acara",
+    "Talk" : "Talk",
     "Review" : "Tinjauan",
     "Mail" : "Email",
     "Birthday" : "Tanggal lahir"
